# REEXPORT FROM ARKHE

#' @importFrom arkhe replace_NA
#' @export
arkhe::replace_NA

#' @importFrom arkhe replace_zero
#' @export
arkhe::replace_zero

#' @importFrom arkhe remove_NA
#' @export
arkhe::remove_NA

#' @importFrom arkhe remove_zero
#' @export
arkhe::remove_zero

#' @importFrom arkhe remove_constant
#' @export
arkhe::remove_constant

#' @importFrom aion calendar
#' @export
aion::calendar

#' @importFrom aion BP
#' @export
aion::BP

#' @importFrom aion b2k
#' @export
aion::b2k

#' @importFrom aion BC
#' @export
aion::BC

#' @importFrom aion BCE
#' @export
aion::BCE

#' @importFrom aion AD
#' @export
aion::AD

#' @importFrom aion CE
#' @export
aion::CE

#' @importFrom aion start
#' @export
aion::start

#' @importFrom aion end
#' @export
aion::start

#' @importFrom aion time
#' @export
aion::time

#' @importFrom aion year_axis
#' @export
aion::year_axis
